==> func_adl_servicex_xaodr22-1.1.4.22.2.113-py3-none-any.whl: func_adl_servicex_xaodr22/xAOD/jetroi_v2.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
import func_adl_servicex_xaodr22

_method_map = {
    'eta': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'eta',
        'return_type': 'float',
    },
    'phi': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'phi',
        'return_type': 'float',
    },
    'roiWord': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'roiWord',
        'return_type': 'unsigned int',
    },
    'etLarge': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'etLarge',
        'return_type': 'float',
    },
    'etSmall': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'etSmall',
        'return_type': 'float',
    },
    'etScale': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'etScale',
        'return_type': 'float',
    },
    'thrPattern': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'thrPattern',
        'return_type': 'unsigned int',
    },
    'et4x4': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'et4x4',
        'return_type': 'float',
    },
    'et6x6': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'et6x6',
        'return_type': 'float',
    },
    'et8x8': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'et8x8',
        'return_type': 'float',
    },
    'thrNames': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'thrNames',
        'return_type_element': 'string',
        'return_type_collection': 'const vector<string>',
    },
    'thrValues': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'thrValues',
        'return_type_element': 'float',
        'return_type_collection': 'const vector<float>',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'index',
        'return_type': 'int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'trackIndices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'trackIndices',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}


T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])
        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTrigger/versions/JetRoI_v2.h',
            'body_includes': ["xAODTrigger/versions/JetRoI_v2.h"],
        })
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class JetRoI_v2:
    "A class"

    def eta(self) -> float:
        "A method"
        ...

    def phi(self) -> float:
        "A method"
        ...

    def roiWord(self) -> int:
        "A method"
        ...

    def etLarge(self) -> float:
        "A method"
        ...

    def etSmall(self) -> float:
        "A method"
        ...

    def etScale(self) -> float:
        "A method"
        ...

    def thrPattern(self) -> int:
        "A method"
        ...

    def et4x4(self) -> float:
        "A method"
        ...

    def et6x6(self) -> float:
        "A method"
        ...

    def et8x8(self) -> float:
        "A method"
        ...

    def thrNames(self) -> func_adl_servicex_xaodr22.vector_str_.vector_str_:
        "A method"
        ...

    def thrValues(self) -> func_adl_servicex_xaodr22.vector_float_.vector_float_:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    def trackIndices(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[str]:
        "A method"
        ...

==> func_adl_servicex_xaodr22-2.0.1.22.2.107-py3-none-any.whl: func_adl_servicex_xaodr22/xAOD/jetroi_v2.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr22

_method_map = {
    'eta': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'eta',
        'return_type': 'float',
    },
    'phi': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'phi',
        'return_type': 'float',
    },
    'roiWord': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'roiWord',
        'return_type': 'unsigned int',
    },
    'etLarge': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'etLarge',
        'return_type': 'float',
    },
    'etSmall': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'etSmall',
        'return_type': 'float',
    },
    'etScale': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'etScale',
        'return_type': 'float',
    },
    'thrPattern': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'thrPattern',
        'return_type': 'unsigned int',
    },
    'et4x4': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'et4x4',
        'return_type': 'float',
    },
    'et6x6': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'et6x6',
        'return_type': 'float',
    },
    'et8x8': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'et8x8',
        'return_type': 'float',
    },
    'thrNames': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'thrNames',
        'return_type_element': 'string',
        'return_type_collection': 'const vector<string>',
    },
    'thrValues': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'thrValues',
        'return_type_element': 'float',
        'return_type_collection': 'const vector<float>',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'index',
        'return_type': 'int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'trackIndices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'trackIndices',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::JetRoI_v2',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])
        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTrigger/versions/JetRoI_v2.h',
            'body_includes': ["xAODTrigger/versions/JetRoI_v2.h"],
        })
        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class JetRoI_v2:
    "A class"


    def eta(self) -> float:
        "A method"
        ...

    def phi(self) -> float:
        "A method"
        ...

    def roiWord(self) -> int:
        "A method"
        ...

    def etLarge(self) -> float:
        "A method"
        ...

    def etSmall(self) -> float:
        "A method"
        ...

    def etScale(self) -> float:
        "A method"
        ...

    def thrPattern(self) -> int:
        "A method"
        ...

    def et4x4(self) -> float:
        "A method"
        ...

    def et6x6(self) -> float:
        "A method"
        ...

    def et8x8(self) -> float:
        "A method"
        ...

    def thrNames(self) -> func_adl_servicex_xaodr22.vector_str_.vector_str_:
        "A method"
        ...

    def thrValues(self) -> func_adl_servicex_xaodr22.vector_float_.vector_float_:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    def trackIndices(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...
